<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Matrimony
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function matrimony_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
    global $post;
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}
    $sidebar = 'right-sidebar';
    if ( is_singular() ){        
        $sidebar = get_post_meta( esc_attr($post->ID) , 'matrimony_sidebar_layout', true ) ;  
    } elseif( is_404() ){
        $sidebar = 'no-sidebar';
    } else{
        $sidebar = get_theme_mod('matrimony_archive_setting_sidebar_option','right-sidebar'); 
    }
    $classes[] = esc_attr( $sidebar ); 

    // Adds a class of no-sidebar when there is no sidebar present.
    
    return $classes;
}
add_filter( 'body_class', 'matrimony_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function matrimony_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'matrimony_pingback_header' );

/**
 * Register the required plugins for this theme.
 * 
 * This function is hooked into `tgmpa_register`, which is fired on the WP `init` action on priority 10.
 */
function matrimony_register_required_plugins() {
    /*
     * Array of plugin arrays. Required keys are name and slug.
     * If the source is NOT from the .org repo, then source is also required.
     */
    $plugins = array(     
        array(
            'name'      => esc_html__( 'Theme Once Click Demo Importer', 'matrimony' ), //The plugin name
            'slug'      => 'theme-one-click-demo-import',  // The plugin slug (typically the folder name)
            'required'  => false,  // If false, the plugin is only 'recommended' instead of required.
            'force_activation'   => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
            'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
        ),    
               
    );

    $config = array(
        'id'           => 'matrimony',        // Unique ID for hashing notices for multiple instances of TGMPA.
        'default_path' => '',                      // Default absolute path to bundled plugins.     
        'has_notices'  => true,                    // Show admin notices or not.
        'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
        'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
        'is_automatic' => false,                   // Automatically activate plugins after installation or not.
        'message'      => '',                      // Message to output right before the plugins table.
        );

    tgmpa( $plugins, $config );
}
add_action( 'tgmpa_register', 'matrimony_register_required_plugins' );
